package com.ruoyi.project.business.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.business.domain.TjElevatorParaDetail;
import com.ruoyi.project.business.mapper.TjElevatorParaDetailMapper;
import com.ruoyi.project.business.service.ITjElevatorParaDetailService;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2024-05-20
 */
@Service
public class TjElevatorParaDetailServiceImpl extends
    ServiceImpl<TjElevatorParaDetailMapper, TjElevatorParaDetail> implements ITjElevatorParaDetailService {

    @Resource
    private TjElevatorParaDetailMapper tjElevatorParaDetailMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TjElevatorParaDetail selectTjElevatorParaDetailById(Long id) {
        return tjElevatorParaDetailMapper.selectTjElevatorParaDetailById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tjElevatorParaDetail 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TjElevatorParaDetail> selectTjElevatorParaDetailList(TjElevatorParaDetail tjElevatorParaDetail) {
        return tjElevatorParaDetailMapper.selectTjElevatorParaDetailList(tjElevatorParaDetail);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tjElevatorParaDetail 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTjElevatorParaDetail(TjElevatorParaDetail tjElevatorParaDetail) {
        tjElevatorParaDetail.setCreateTime(DateUtils.getNowDate());
        return tjElevatorParaDetailMapper.insertTjElevatorParaDetail(tjElevatorParaDetail);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tjElevatorParaDetail 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTjElevatorParaDetail(TjElevatorParaDetail tjElevatorParaDetail) {
        tjElevatorParaDetail.setUpdateTime(DateUtils.getNowDate());
        return tjElevatorParaDetailMapper.updateTjElevatorParaDetail(tjElevatorParaDetail);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTjElevatorParaDetailByIds(Long[] ids) {
        return tjElevatorParaDetailMapper.deleteTjElevatorParaDetailByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTjElevatorParaDetailById(Long id) {
        return tjElevatorParaDetailMapper.deleteTjElevatorParaDetailById(id);
    }
}
