package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.business.domain.TjElevatorParaDetail;
import com.ruoyi.project.business.service.ITjElevatorParaDetailService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-05-20
 */
@RestController
@RequestMapping("/business/elevatorDetail")
public class TjElevatorParaDetailController extends BaseController
{
    @Autowired
    private ITjElevatorParaDetailService tjElevatorParaDetailService;

    /**
     * 查询【请填写功能名称】列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TjElevatorParaDetail tjElevatorParaDetail)
    {
        startPage();
        List<TjElevatorParaDetail> list = tjElevatorParaDetailService.selectTjElevatorParaDetailList(tjElevatorParaDetail);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TjElevatorParaDetail tjElevatorParaDetail)
    {
        List<TjElevatorParaDetail> list = tjElevatorParaDetailService.selectTjElevatorParaDetailList(tjElevatorParaDetail);
        ExcelUtil<TjElevatorParaDetail> util = new ExcelUtil<TjElevatorParaDetail>(TjElevatorParaDetail.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tjElevatorParaDetailService.selectTjElevatorParaDetailById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TjElevatorParaDetail tjElevatorParaDetail)
    {
        return toAjax(tjElevatorParaDetailService.insertTjElevatorParaDetail(tjElevatorParaDetail));
    }

    /**
     * 修改【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TjElevatorParaDetail tjElevatorParaDetail)
    {
        return toAjax(tjElevatorParaDetailService.updateTjElevatorParaDetail(tjElevatorParaDetail));
    }

    /**
     * 删除【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tjElevatorParaDetailService.deleteTjElevatorParaDetailByIds(ids));
    }
}
